.. pytest-wdl documentation master file, created by
   sphinx-quickstart on Fri Aug  9 13:48:03 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pytest-wdl's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   manual.md
   modules.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
